import { ChangeDetectorRef, Component, EventEmitter, Input, Output } from '@angular/core';
import { ToastrService } from 'ngx-toastr';
import { AppraisalFormModel } from 'src/app/shared/model/appraisal-form.model';
import { AppraisalModel } from 'src/app/shared/model/appraisal.model';
import { EvaluationCycleModel, MyEvaluationCycleModel } from 'src/app/shared/model/evaluation-cycle.model';
import { EvaluationAssessmentService } from 'src/app/shared/services/evaluation-assessment.service';
import { EvaluationCycleService } from 'src/app/shared/services/evaluation-cycle.service';


@Component({
  selector: 'app-edit-evaluation-form',
  templateUrl: './edit-evaluation-form.component.html',
  styleUrls: ['./edit-evaluation-form.component.scss']
})
export class EditEvaluationFormComponent {
  @Input() pathTitle = ['การประเมินจัดการประสิทธิภาพ', 'รอบการประเมิน', 'กำหนดฟอร์มเอกสาร', 'เเก้ไขฟอร์มตามรอบการประเมิน'];
  @Output() sendPathTitle: EventEmitter<string[]> = new EventEmitter<string[]>();
  @Output() sendGroupShow: EventEmitter<string> = new EventEmitter<string>();
  @Input() evaluationRoundId = ''

  currentPage = 1
  page = Array.from({ length: 1 }, (_, i) => i + 1);
  search = ""

  assessmentList: AppraisalModel[] = []

  evaluationRound:EvaluationCycleModel = new MyEvaluationCycleModel()

  isChecked: boolean = false; 
  
  apsassessy = ""
  constructor(private toastr: ToastrService,
    private cdr: ChangeDetectorRef,
    private evaluationAssessmentService: EvaluationAssessmentService,
    private evaluationCycleService: EvaluationCycleService
  ) {

  }

  ngOnInit(): void {

  }
  ngOnChanges(): void {
    if (this.evaluationRoundId) {
      this.getAssessmentId();
      this.getAssessmentList();
    }

  }
  getAssessmentId() {
    this.evaluationCycleService.getById(this.evaluationRoundId!).subscribe({
      next: response => {
        this.evaluationRound = response
        this.cdr.detectChanges();
      },
      error: err => {
        console.error('Error fetching evaluation cycles:', err);
      }
    });

  }
  getAssessmentList() {
    this.evaluationAssessmentService.getById(this.evaluationRoundId!).subscribe({
      next: response => {
        this.assessmentList = response
        this.cdr.detectChanges();
      },
      error: err => {
        console.error('Error fetching evaluation cycles:', err);
      }
    });
  }
  assessmentListFilter() {
    return this.assessmentList.filter(x =>
      x.apsassessy.fname.toLowerCase().includes(this.search.toLowerCase()) ||
      x.apsassessy.lname.toLowerCase().includes(this.search.toLowerCase()) ||
      x.apsassessy.efname.toLowerCase().includes(this.search.toLowerCase()) ||
      x.apsassessy.elname.toLowerCase().includes(this.search.toLowerCase()) ||
      x.masfromEvaluationRound.evaluationRoundId.toLowerCase().includes(this.search.toLowerCase()) ||
      x.apsassessy.employeeId.toLowerCase().includes(this.search.toLowerCase())
    )
  }
  searchChange() {
    this.currentPage = 1;
    const filteredData = this.assessmentListFilter();
    this.page = Array.from({ length: Math.ceil(filteredData.length / 10) }, (_, i) => i + 1);
  }

  openModalClass(id: string) {
    document.getElementById(id)?.classList.add('open');
    document.getElementById(id)?.classList.remove('hidden');
    setTimeout(() => {
      document.getElementById(id)?.setAttribute('aria-overlay', 'true')
    }, 10);

  }

  closeModalClass(id: string) {
    const modal = document.getElementById(id);
    if (modal) {
      modal.classList.add("hidden"); // ซ่อน Modal
    }
  }
 


  saveAssessmentList() {
    let body = this.assessmentList.filter(x => x.active == true)
    if (body.length > 0) {
      this.evaluationAssessmentService.postList(body).subscribe({
        next: response => {
          if (response.success) {
            this.showAlert(response.message, 'success')
            this.getAssessmentList();
          } else {
          }
        }
      })
    } else {
      this.showAlert('ไม่พบรายการ', 'error')
    }
  }

  openAddRoundModel(evaluationRoundId:string,apsassessy:string,model:string) {
      this.openModalClass(model);
      this.evaluationRoundId = evaluationRoundId
      this.apsassessy = apsassessy
      this.getApsassessy()
    }
    
  getApsassessy(){
    this.evaluationAssessmentService.getApsassessy(this.evaluationRoundId,this.apsassessy).subscribe({
      next: response => {
      console.log("🚀 ~ EditEvaluationFormComponent ~ this.evaluationAssessmentService.getApsassessy ~ response:", response)
        this.cdr.detectChanges();
      },
      error: err => {
        console.error('Error fetching evaluation cycles:', err);
    }
  })
  }
  showAlert(text: string, type: 'success' | 'error') {
    this.toastr[type](text, 'แจ้งเตือน', {
      timeOut: 3000,
      positionClass: 'toast-top-right',
    });
  }



  toggleCheckbox() {
    this.isChecked = !this.isChecked; // สลับสถานะ
  }

  addUser() {

  }



}
